@@ -6,7 +6,7 @@ import os, os.path, sys
 LDLIBS_MAP = {
 	'macosx' : '-lm -lreadline -liconv',
 	'unix' : '-lm -lreadline -liconv',
-	'mingw' : '-lm -liconv',
+	'mingw' : 'lib/iconv.a -lm',
 	'cygwin': '-lm -lreadline -liconv',
 }
 
