@@ -29,6 +29,10 @@
 
 #include"commons.h"
 
+#ifdef KNH_USING_POSIX
+#include<errno.h>
+#endif
+
 /* ************************************************************************ */
 
 #ifdef __cplusplus
@@ -77,48 +81,71 @@ knh_Exception_struct_traverse(Ctx *ctx, knh_Exception_struct *b, f_traverse gc)
 /* ======================================================================== */
 /* [constructors] */
 
-/* @method Exception! Exception.new(String e, String msg, Any bag) */
+/* @method Exception! Exception.new:init(String e, String msg, Object bag) */
+// new Exception("Security!!", "hogehoge");
+// new Exception("Security!!: hogehoge", null);
 
-static
-Exception* knh_Exception_new(Ctx *ctx, Exception *o, String *e, String *msg, Object *bag)
+Exception* knh_Exception_new__init(Ctx *ctx, Exception *o, String *e, String *msg, Object *bag)
 {
-	DP(o)->eid  = EXPT_Exception; //knh_texpt_forname(ctx, knh_String_tobytes(e), EXPT_Exception);
-	//DEBUG("eid=%d", DP(o)->eid);
-	DP(o)->flag = 0; // knh_texpt_flag(DP(o)->eid);
-	if(IS_NULL(msg)) {
-		KNH_SETv(ctx, DP(o)->message, e);
+	knh_expt_t eid = EXPT_Exception;
+	if(IS_NOTNULL(e)) {
+		eid = knh_texpt_forname(ctx, knh_String_tobytes(e), EXPT_unknown);
+	}
+	if(eid == EXPT_unknown) {
+		KNH_WARNING(ctx, "unknown exception: %s", knh_String_tochar(e));
+		DP(o)->eid = EXPT_Exception;
 	}
 	else {
-		knh_wbuf_t cb = knh_Context_wbuf(ctx);
-		knh_write(ctx, cb.w, knh_String_tobytes(e));
-		knh_putc(ctx, cb.w, ':');
-		knh_putc(ctx, cb.w, ' ');
-		knh_write(ctx, cb.w, knh_String_tobytes(msg));
-		KNH_SETv(ctx, DP(o)->message, new_String__wbuf(ctx, cb));
+		DP(o)->eid = eid;
 	}
+	DP(o)->flag = knh_tExpt_flag(DP(o)->eid);
 	KNH_SETv(ctx, DP(o)->bag, bag);
+	{
+		if(IS_NOTNULL(msg)) {
+			knh_wbuf_t wbuf = knh_Context_wbuf(ctx);
+			knh_write__s(ctx, wbuf.w, EXPTN(DP(o)->eid));
+			knh_write__s(ctx, wbuf.w, "!!: ");
+			knh_write(ctx, wbuf.w, knh_String_tobytes(msg));
+			KNH_SETv(ctx, DP(o)->message, new_String__wbuf(ctx, wbuf));
+		}
+		else {
+			int loc = knh_bytes_indexOf(knh_String_tobytes(e), STEXT("!!:"));
+			if(loc > 0 && eid != EXPT_unknown) {
+				KNH_SETv(ctx, DP(o)->message, e);
+				return o;
+			}
+			knh_wbuf_t wbuf = knh_Context_wbuf(ctx);
+			knh_write__s(ctx, wbuf.w, EXPTN(DP(o)->eid));
+			knh_write__s(ctx, wbuf.w, "!!");
+			if(loc > 0) {
+				knh_write__s(ctx, wbuf.w, ": ");
+				knh_write(ctx, wbuf.w, knh_bytes_last(knh_String_tobytes(e), loc+3));
+			}
+			KNH_SETv(ctx, DP(o)->message, new_String__wbuf(ctx, wbuf));
+		}
+	}
 	return o;
 }
 
 /* ------------------------------------------------------------------------ */
 
-Exception* new_Exception(Ctx *ctx, String *msg)
+KNHAPI(Exception*) new_Exception(Ctx *ctx, String *msg)
 {
 	knh_Exception_t* o =
 		(knh_Exception_t*)new_Object_malloc(ctx, FLAG_Exception, CLASS_Exception, sizeof(knh_Exception_struct));
 	knh_Exception_struct_init(ctx, DP(o), 0, NULL);
-	knh_Exception_new(ctx, o, msg, (String*)KNH_NULL, (Object*)KNH_NULL);
+	knh_Exception_new__init(ctx, o, msg, (String*)KNH_NULL, (Object*)KNH_NULL);
 	return o;
 }
 
 /* ------------------------------------------------------------------------ */
 
-Exception* new_Exception__b(Ctx *ctx, knh_bytes_t msg)
+KNHAPI(Exception*) new_Exception__b(Ctx *ctx, knh_bytes_t msg)
 {
 	knh_Exception_t* o =
 		(knh_Exception_t*)new_Object_malloc(ctx, FLAG_Exception, CLASS_Exception, sizeof(knh_Exception_struct));
 	knh_Exception_struct_init(ctx, DP(o), 0, NULL);
-	knh_Exception_new(ctx, o, new_String(ctx, msg, NULL), (String*)KNH_NULL, (Object*)KNH_NULL);
+	knh_Exception_new__init(ctx, o, new_String(ctx, msg, NULL), (String*)KNH_NULL, (Object*)KNH_NULL);
 	return o;
 }
 
@@ -132,16 +159,29 @@ Exception* new_Exception__Nue(Ctx *ctx, knh_Nue_t *nue)
 		(knh_Exception_t*)new_Object_malloc(ctx, FLAG_Exception, CLASS_Exception, sizeof(knh_Exception_struct));
 	knh_Exception_struct_init(ctx, DP(o), 0, NULL);
 	if(nue->orign == NULL) {
-		knh_Exception_new(ctx, o, new_String(ctx, B((char*)nue->str), NULL), (String*)KNH_NULL, (Object*)KNH_NULL);
+		knh_Exception_new__init(ctx, o, new_String(ctx, B((char*)nue->str), NULL), (String*)KNH_NULL, (Object*)KNH_NULL);
 	}
 	else {
-		knh_Exception_new(ctx, o, (String*)nue->orign, (String*)KNH_NULL, (Object*)KNH_NULL);
+		knh_Exception_new__init(ctx, o, (String*)nue->orign, (String*)KNH_NULL, (Object*)KNH_NULL);
 	}
 	return o;
 }
 
 /* ------------------------------------------------------------------------ */
 
+KNHAPI(Exception*) new_Exception__errno(Ctx *ctx)
+{
+#ifdef KNH_USING_POSIX
+	char buf[40];
+	knh_snprintf(buf, sizeof(buf), "Errno!!: errno=%d", errno);
+	return new_Exception__b(ctx, B(buf));
+#else
+	return new_Exception__s(ctx, "Error!!: errno=UNKNOWN");
+#endif
+}
+
+/* ------------------------------------------------------------------------ */
+
 
 #ifdef __cplusplus
 }
