@@ -479,8 +479,8 @@ void knh_Int__d(Ctx *ctx, Int *o, OutputStream *w, String *m);
 void knh_Int__u(Ctx *ctx, Int *o, OutputStream *w, String *m);
 void knh_Int__f(Ctx *ctx, Int *o, OutputStream *w, String *m);
 void knh_Int__x(Ctx *ctx, Int *o, OutputStream *w, String *m);
-void knh_write_bits(Ctx *ctx, OutputStream *w, knh_uint64_t n, int bits);
-void knh_Int__bits(Ctx *ctx, Int *b, OutputStream *w, String *m);
+void knh_write_bits(Ctx *ctx, OutputStream *w, knh_uint64_t n, size_t bits);
+void knh_Int__bits(Ctx *ctx, Int *o, OutputStream *w, String *m);
 /* ../class/konoha/knh_IntUnit.c */
 void knh_IntUnit_struct_init(Ctx *ctx, knh_IntUnit_struct *b, int init, Object *cs);
 void knh_IntUnit_struct_traverse(Ctx *ctx, knh_IntUnit_struct *b, f_traverse gc);
@@ -634,6 +634,7 @@ Object *knh_OutputStream_open(Ctx *ctx, OutputStream *o, String *urn, String *mo
 void knh_OutputStream_putc(Ctx *ctx, OutputStream *o, int ch);
 void knh_OutputStream_write(Ctx *ctx, OutputStream *o, knh_bytes_t buf);
 void knh_OutputStream_flush(Ctx *ctx, OutputStream *o);
+void knh_OutputStream_clear(Ctx *ctx, OutputStream *o);
 void knh_OutputStream_close(Ctx *ctx, OutputStream *o);
 int knh_OutputStream_isClosed(OutputStream *o);
 void knh_OutputStream_indent_inc(Ctx *ctx, OutputStream *o);
