@@ -91,7 +91,7 @@ extern "C" {
 #define TT_BITANDE                      ((knh_token_t)48)
 #define TT_ALTLET                       ((knh_token_t)49)
 #define TT_QUESTION                     ((knh_token_t)50)
-#define TT_SUBSETE                      ((knh_token_t)51)
+#define TT_ITR                          ((knh_token_t)51)
 #define TT_SUBSET                       ((knh_token_t)52)
 #define TT_OFFSET                       ((knh_token_t)53)
 #define TT_COLON                        ((knh_token_t)54)
@@ -111,75 +111,79 @@ extern "C" {
 #define TT_LTE                          ((knh_token_t)68)
 #define TT_GT                           ((knh_token_t)69)
 #define TT_GTE                          ((knh_token_t)70)
-#define TT_LOR                          ((knh_token_t)71)
-#define TT_FMT                          ((knh_token_t)72)
-#define TT_LSHIFT                       ((knh_token_t)73)
-#define TT_RSHIFT                       ((knh_token_t)74)
-#define TT_ADD                          ((knh_token_t)75)
-#define TT_SUB                          ((knh_token_t)76)
-#define TT_DIV                          ((knh_token_t)77)
-#define TT_MOD                          ((knh_token_t)78)
-#define TT_MUL                          ((knh_token_t)79)
-#define TT_LAND                         ((knh_token_t)80)
-#define TT_LNOT                         ((knh_token_t)81)
-#define TT_XOR                          ((knh_token_t)82)
-#define TT_NEXT                         ((knh_token_t)83)
-#define TT_PREV                         ((knh_token_t)84)
-#define TT_NEG                          ((knh_token_t)85)
-#define TT_NUM                          ((knh_token_t)86)
+#define TT_MATCH                        ((knh_token_t)71)
+#define TT_LOR                          ((knh_token_t)72)
+#define TT_FMT                          ((knh_token_t)73)
+#define TT_LSHIFT                       ((knh_token_t)74)
+#define TT_RSHIFT                       ((knh_token_t)75)
+#define TT_ADD                          ((knh_token_t)76)
+#define TT_SUB                          ((knh_token_t)77)
+#define TT_DIV                          ((knh_token_t)78)
+#define TT_MOD                          ((knh_token_t)79)
+#define TT_MUL                          ((knh_token_t)80)
+#define TT_LAND                         ((knh_token_t)81)
+#define TT_LNOT                         ((knh_token_t)82)
+#define TT_XOR                          ((knh_token_t)83)
+#define TT_NEXT                         ((knh_token_t)84)
+#define TT_PREV                         ((knh_token_t)85)
+#define TT_NEG                          ((knh_token_t)86)
+#define TT_NUM                          ((knh_token_t)87)
 #define knh_Token_isNUM(tk_)            (SP(tk_)->tt == TT_NUM)
-#define TT_STR                          ((knh_token_t)87)
+#define TT_STR                          ((knh_token_t)88)
 #define knh_Token_isSTR(tk_)            (SP(tk_)->tt == TT_STR)
-#define TT_TSTR                         ((knh_token_t)88)
+#define TT_TSTR                         ((knh_token_t)89)
 #define knh_Token_isTSTR(tk_)           (SP(tk_)->tt == TT_TSTR)
-#define TT_EVAL                         ((knh_token_t)89)
+#define TT_EVAL                         ((knh_token_t)90)
 #define knh_Token_isEVAL(tk_)           (SP(tk_)->tt == TT_EVAL)
-#define TT_LABEL                        ((knh_token_t)90)
+#define TT_LABEL                        ((knh_token_t)91)
 #define knh_Token_isLABEL(tk_)          (SP(tk_)->tt == TT_LABEL)
-#define TT_METAN                        ((knh_token_t)91)
+#define TT_METAN                        ((knh_token_t)92)
 #define knh_Token_isMETAN(tk_)          (SP(tk_)->tt == TT_METAN)
-#define TT_PROPN                        ((knh_token_t)92)
+#define TT_PROPN                        ((knh_token_t)93)
 #define knh_Token_isPROPN(tk_)          (SP(tk_)->tt == TT_PROPN)
-#define TT_URN                          ((knh_token_t)93)
+#define TT_URN                          ((knh_token_t)94)
 #define knh_Token_isURN(tk_)            (SP(tk_)->tt == TT_URN)
-#define TT_MT                           ((knh_token_t)94)
+#define TT_MT                           ((knh_token_t)95)
 #define knh_Token_isMT(tk_)             (SP(tk_)->tt == TT_MT)
-#define TT_CONSTN                       ((knh_token_t)95)
+#define TT_CONSTN                       ((knh_token_t)96)
 #define knh_Token_isCONSTN(tk_)         (SP(tk_)->tt == TT_CONSTN)
-#define TT_TYPEN                        ((knh_token_t)96)
+#define TT_TYPEN                        ((knh_token_t)97)
 #define knh_Token_isTYPEN(tk_)          (SP(tk_)->tt == TT_TYPEN)
-#define TT_CMETHODN                     ((knh_token_t)97)
+#define TT_CMETHODN                     ((knh_token_t)98)
 #define knh_Token_isCMETHODN(tk_)       (SP(tk_)->tt == TT_CMETHODN)
-#define TT_NAME                         ((knh_token_t)98)
+#define TT_NAME                         ((knh_token_t)99)
 #define knh_Token_isNAME(tk_)           (SP(tk_)->tt == TT_NAME)
-#define TT_MN                           ((knh_token_t)99)
+#define TT_MN                           ((knh_token_t)100)
 #define knh_Token_isMN(tk_)             (SP(tk_)->tt == TT_MN)
-#define TT_FN                           ((knh_token_t)100)
+#define TT_FN                           ((knh_token_t)101)
 #define knh_Token_isFN(tk_)             (SP(tk_)->tt == TT_FN)
-#define TT_CID                          ((knh_token_t)101)
+#define TT_CID                          ((knh_token_t)102)
 #define knh_Token_isCID(tk_)            (SP(tk_)->tt == TT_CID)
-#define TT_CONST                        ((knh_token_t)102)
+#define TT_CONST                        ((knh_token_t)103)
 #define knh_Token_isCONST(tk_)          (SP(tk_)->tt == TT_CONST)
-#define TT_MTDMPR                       ((knh_token_t)103)
+#define TT_MTDMPR                       ((knh_token_t)104)
 #define knh_Token_isMTDMPR(tk_)         (SP(tk_)->tt == TT_MTDMPR)
-#define TT_EBPIDX                       ((knh_token_t)104)
+#define TT_EBPIDX                       ((knh_token_t)105)
 #define knh_Token_isEBPIDX(tk_)         (SP(tk_)->tt == TT_EBPIDX)
-#define TT_SFPIDX                       ((knh_token_t)105)
+#define TT_SFPIDX                       ((knh_token_t)106)
 #define knh_Token_isSFPIDX(tk_)         (SP(tk_)->tt == TT_SFPIDX)
-#define TT_FLDIDX                       ((knh_token_t)106)
+#define TT_FLDIDX                       ((knh_token_t)107)
 #define knh_Token_isFLDIDX(tk_)         (SP(tk_)->tt == TT_FLDIDX)
-#define TT_OBJIDX                       ((knh_token_t)107)
+#define TT_OBJIDX                       ((knh_token_t)108)
 #define knh_Token_isOBJIDX(tk_)         (SP(tk_)->tt == TT_OBJIDX)
-#define TT_SYSCONST                     ((knh_token_t)108)
+#define TT_SYSCONST                     ((knh_token_t)109)
 #define knh_Token_isSYSCONST(tk_)       (SP(tk_)->tt == TT_SYSCONST)
-#define TT_ASIS                         ((knh_token_t)109)
-#define TT_ERR                          ((knh_token_t)110)
+#define TT_ASIS                         ((knh_token_t)110)
+#define TT_ERR                          ((knh_token_t)111)
 #define knh_Token_isERR(tk_)            (SP(tk_)->tt == TT_ERR)
-#define TT_EOT                          ((knh_token_t)111)
+#define TT_EOT                          ((knh_token_t)112)
 #define knh_Token_isEOT(tk_)            (SP(tk_)->tt == TT_EOT)
-#define KNH_TOKEN_MAXSIZ                ((knh_token_t)112)
+#define KNH_TOKEN_MAXSIZ                ((knh_token_t)113)
 
 /* ------------------------------------------------------------------------ */
+#ifndef METHODN_opItr
+#define METHODN_opItr                   METHODN_NONAME
+#endif
 #ifndef METHODN_opALT
 #define METHODN_opALT                   METHODN_NONAME
 #endif
@@ -222,6 +226,9 @@ extern "C" {
 #ifndef METHODN_opGte
 #define METHODN_opGte                   METHODN_NONAME
 #endif
+#ifndef METHODN_opMatch
+#define METHODN_opMatch                 METHODN_NONAME
+#endif
 #ifndef METHODN_opLor
 #define METHODN_opLor                   METHODN_NONAME
 #endif
