@@ -550,11 +550,17 @@ void knh_Object_free(Ctx *ctx, knh_Object_t *o)
 		}
 		break;
 
+	case CLASS_Regex :
+		{
+			knh_Regex_traverse(ctx, (knh_Regex_t*)o, knh_Object_RCsweep);
+			break;
+		}
+
 	case CLASS_Context:
 		{
 			knh_Context_traverse(ctx, (Context*)o, knh_Object_RCsweep);
-			return ;
 		}
+		return ;
 
 	default :
 		{
@@ -690,6 +696,12 @@ void knh_Object_traverse(Ctx *ctx, knh_Object_t *o, f_traverse ftr)
 		}
 		break;
 
+	case CLASS_Regex :
+		{
+			knh_Regex_traverse(ctx, (knh_Regex_t*)o, ftr);
+			break;
+		}
+
 	case CLASS_Context:
 		{
 			knh_Context_traverse(ctx, (Context*)o, ftr);
